@@ -21,8 +21,10 @@ import six
 from cliff import command
 from cliff import lister
 from cliff import show
+from keystoneclient.openstack.common.apiclient import exceptions as ksc_exc
 
 from openstackclient.common import utils
+from openstackclient.i18n import _  # noqa
 
 
 class CreateUser(show.ShowOne):
@@ -34,40 +36,45 @@ class CreateUser(show.ShowOne):
         parser = super(CreateUser, self).get_parser(prog_name)
         parser.add_argument(
             'name',
-            metavar='<user-name>',
-            help='New user name',
+            metavar='<name>',
+            help=_('New user name'),
+        )
+        parser.add_argument(
+            '--project',
+            metavar='<project>',
+            help=_('Default project (name or ID)'),
         )
         parser.add_argument(
             '--password',
-            metavar='<user-password>',
-            help='New user password',
+            metavar='<password>',
+            help=_('Set user password'),
         )
         parser.add_argument(
             '--password-prompt',
             dest="password_prompt",
             action="store_true",
-            help='Prompt interactively for password',
+            help=_('Prompt interactively for password'),
         )
         parser.add_argument(
             '--email',
-            metavar='<user-email>',
-            help='New user email address',
-        )
-        parser.add_argument(
-            '--project',
-            metavar='<project>',
-            help='Set default project (name or ID)',
+            metavar='<email-address>',
+            help=_('Set user email address'),
         )
         enable_group = parser.add_mutually_exclusive_group()
         enable_group.add_argument(
             '--enable',
             action='store_true',
-            help='Enable user (default)',
+            help=_('Enable user (default)'),
         )
         enable_group.add_argument(
             '--disable',
             action='store_true',
-            help='Disable user',
+            help=_('Disable user'),
+        )
+        parser.add_argument(
+            '--or-show',
+            action='store_true',
+            help=_('Return existing user'),
         )
         return parser
 
@@ -89,13 +96,24 @@ class CreateUser(show.ShowOne):
         if parsed_args.password_prompt:
             parsed_args.password = utils.get_password(self.app.stdin)
 
-        user = identity_client.users.create(
-            parsed_args.name,
-            parsed_args.password,
-            parsed_args.email,
-            tenant_id=project_id,
-            enabled=enabled,
-        )
+        try:
+            user = identity_client.users.create(
+                parsed_args.name,
+                parsed_args.password,
+                parsed_args.email,
+                tenant_id=project_id,
+                enabled=enabled,
+            )
+        except ksc_exc.Conflict as e:
+            if parsed_args.or_show:
+                user = utils.find_resource(
+                    identity_client.users,
+                    parsed_args.name,
+                )
+                self.log.info('Returning existing user %s', user.name)
+            else:
+                raise e
+
         # NOTE(dtroyer): The users.create() method wants 'tenant_id' but
         #                the returned resource has 'tenantId'.  Sigh.
         #                We're using project_id now inside OSC so there.
@@ -119,7 +137,7 @@ class DeleteUser(command.Command):
         parser.add_argument(
             'user',
             metavar='<user>',
-            help='User to delete (name or ID)',
+            help=_('User to delete (name or ID)'),
         )
         return parser
 
@@ -146,13 +164,13 @@ class ListUser(lister.Lister):
         parser.add_argument(
             '--project',
             metavar='<project>',
-            help='Filter users by project (name or ID)',
+            help=_('Filter users by project (name or ID)'),
         )
         parser.add_argument(
             '--long',
             action='store_true',
             default=False,
-            help='List additional fields in output')
+            help=_('List additional fields in output'))
         return parser
 
     def take_action(self, parsed_args):
@@ -236,44 +254,44 @@ class SetUser(command.Command):
         parser.add_argument(
             'user',
             metavar='<user>',
-            help='User to change (name or ID)',
+            help=_('User to change (name or ID)'),
         )
         parser.add_argument(
             '--name',
-            metavar='<new-user-name>',
-            help='New user name',
+            metavar='<name>',
+            help=_('Set user name'),
+        )
+        parser.add_argument(
+            '--project',
+            metavar='<project>',
+            help=_('Set default project (name or ID)'),
         )
         parser.add_argument(
             '--password',
             metavar='<user-password>',
-            help='New user password',
+            help=_('Set user password'),
         )
         parser.add_argument(
             '--password-prompt',
             dest="password_prompt",
             action="store_true",
-            help='Prompt interactively for password',
+            help=_('Prompt interactively for password'),
         )
         parser.add_argument(
             '--email',
-            metavar='<user-email>',
-            help='New user email address',
-        )
-        parser.add_argument(
-            '--project',
-            metavar='<project>',
-            help='New default project (name or ID)',
+            metavar='<email-address>',
+            help=_('Set user email address'),
         )
         enable_group = parser.add_mutually_exclusive_group()
         enable_group.add_argument(
             '--enable',
             action='store_true',
-            help='Enable user (default)',
+            help=_('Enable user (default)'),
         )
         enable_group.add_argument(
             '--disable',
             action='store_true',
-            help='Disable user',
+            help=_('Disable user'),
         )
         return parser
 
@@ -339,7 +357,7 @@ class ShowUser(show.ShowOne):
         parser.add_argument(
             'user',
             metavar='<user>',
-            help='User to display (name or ID)',
+            help=_('User to display (name or ID)'),
         )
         return parser
 
@@ -347,20 +365,37 @@ class ShowUser(show.ShowOne):
         self.log.debug('take_action(%s)', parsed_args)
         identity_client = self.app.client_manager.identity
 
-        user = utils.find_resource(
-            identity_client.users,
-            parsed_args.user,
-        )
-
-        if 'tenantId' in user._info:
-            user._info.update(
-                {'project_id': user._info.pop('tenantId')}
-            )
-        if 'tenant_id' in user._info:
-            user._info.update(
-                {'project_id': user._info.pop('tenant_id')}
-            )
-
         info = {}
-        info.update(user._info)
+        try:
+            user = utils.find_resource(
+                identity_client.users,
+                parsed_args.user,
+            )
+            info.update(user._info)
+        except ksc_exc.Forbidden as e:
+            auth_ref = self.app.client_manager.auth_ref
+            if (
+                parsed_args.user == auth_ref.user_id or
+                parsed_args.user == auth_ref.username
+            ):
+                # Ask for currently auth'ed project so return it
+                info = {
+                    'id': auth_ref.user_id,
+                    'name': auth_ref.username,
+                    'project_id': auth_ref.project_id,
+                    # True because we don't get this far if it is disabled
+                    'enabled': True,
+                }
+            else:
+                raise e
+
+        if 'tenantId' in info:
+            info.update(
+                {'project_id': info.pop('tenantId')}
+            )
+        if 'tenant_id' in info:
+            info.update(
+                {'project_id': info.pop('tenant_id')}
+            )
+
         return zip(*sorted(six.iteritems(info)))
